==> 2.0.0.tar.gz: lib/src/utils/model_utils/video_feed_configuration_util.dart <==
import '../../models/video_feed_configuration.dart';
import 'android_font_info_util.dart';
import 'ios_font_info_util.dart';

class VideoFeedConfigurationUtil {
  static Map<String, dynamic> _convertGradientDrawableToJson(
      GradientDrawable gradientDrawable) {
    Map<String, dynamic> json = {};
    if (gradientDrawable.orientation != null) {
      json["orientation"] = gradientDrawable.orientation!.rawName;
    }

    if (gradientDrawable.colors != null) {
      json["colors"] = gradientDrawable.colors!;
    }

    return json;
  }

  static Map<String, dynamic> _convertTitleConfigToJson(
      VideoFeedTitleConfiguration config) {
    Map<String, dynamic> json = {};
    if (config.hidden != null) {
      json["hidden"] = config.hidden!;
    }

    if (config.textColor != null && config.textColor!.isNotEmpty) {
      json["textColor"] = config.textColor!;
    }

    if (config.fontSize != null) {
      json["fontSize"] = config.fontSize!.toDouble();
    }

    if (config.numberOfLines != null) {
      json["numberOfLines"] = config.numberOfLines!;
    }

    if (config.iOSFontInfo != null) {
      json["iOSFontInfo"] = IOSFontInfoUtil.toJson(config.iOSFontInfo!);
    }

    if (config.androidFontInfo != null) {
      json["androidFontInfo"] =
          AndroidFontInfoUtil.toJson(config.androidFontInfo!);
    }

    if (config.gradientDrawable != null) {
      json["gradientDrawable"] =
          _convertGradientDrawableToJson(config.gradientDrawable!);
    }

    return json;
  }

  static Map<String, dynamic> _convertPlayIconConfigToJson(
      VideoFeedPlayIconConfiguration config) {
    Map<String, dynamic> json = {};
    if (config.hidden != null) {
      json["hidden"] = config.hidden!;
    }

    if (config.iconWidth != null) {
      json["iconWidth"] = config.iconWidth!.toDouble();
    }
    return json;
  }

  static Map<String, dynamic> _convertContentPaddingToJson(
      VideoFeedContentPadding contentPadding) {
    Map<String, dynamic> json = {};
    if (contentPadding.top != null) {
      json["top"] = contentPadding.top!;
    }

    if (contentPadding.right != null) {
      json["right"] = contentPadding.right!;
    }

    if (contentPadding.bottom != null) {
      json["bottom"] = contentPadding.bottom!;
    }

    if (contentPadding.left != null) {
      json["left"] = contentPadding.left!;
    }

    return json;
  }

  static Map<String, dynamic> toJson(VideoFeedConfiguration? config) {
    Map<String, dynamic> json = {};
    if (config == null) {
      return json;
    }

    if (config.backgroundColor != null && config.backgroundColor!.isNotEmpty) {
      json["backgroundColor"] = config.backgroundColor!;
    }

    if (config.cornerRadius != null) {
      json["cornerRadius"] = config.cornerRadius!.toDouble();
    }

    if (config.title != null) {
      json["title"] = _convertTitleConfigToJson(config.title!);
    }

    if (config.titlePosition != null) {
      json["titlePosition"] = config.titlePosition!.name;
    }

    if (config.playIcon != null) {
      json["playIcon"] = _convertPlayIconConfigToJson(config.playIcon!);
    }

    if (config.showAdBadge != null) {
      json["showAdBadge"] = config.showAdBadge!;
    }

    if (config.aspectRatio != null) {
      json["aspectRatio"] = config.aspectRatio!;
    }

    if (config.contentPadding != null) {
      json["contentPadding"] =
          _convertContentPaddingToJson(config.contentPadding!);
    }

    if (config.itemSpacing != null) {
      json["itemSpacing"] = config.itemSpacing!;
    }

    if (config.enableAutoplay != null) {
      json["enableAutoplay"] = config.enableAutoplay!;
    }

    if (config.gridColumns != null) {
      json["gridColumns"] = config.gridColumns!;
    }

    return json;
  }
}

==> 2.0.4.tar.gz: lib/src/utils/model_utils/video_feed_configuration_util.dart <==
import '../../models/video_feed_configuration.dart';
import 'android_font_info_util.dart';
import 'ios_font_info_util.dart';

class VideoFeedConfigurationUtil {
  static Map<String, dynamic> _convertGradientDrawableToJson(
      GradientDrawable gradientDrawable) {
    Map<String, dynamic> json = {};
    if (gradientDrawable.orientation != null) {
      json["orientation"] = gradientDrawable.orientation!.rawName;
    }

    if (gradientDrawable.colors != null) {
      json["colors"] = gradientDrawable.colors!;
    }

    return json;
  }

  static Map<String, dynamic> _convertTitleConfigToJson(
      VideoFeedTitleConfiguration config) {
    Map<String, dynamic> json = {};
    if (config.hidden != null) {
      json["hidden"] = config.hidden!;
    }

    if (config.textColor != null && config.textColor!.isNotEmpty) {
      json["textColor"] = config.textColor!;
    }

    if (config.fontSize != null) {
      json["fontSize"] = config.fontSize!.toDouble();
    }

    if (config.numberOfLines != null) {
      json["numberOfLines"] = config.numberOfLines!;
    }

    if (config.iOSFontInfo != null) {
      json["iOSFontInfo"] = IOSFontInfoUtil.toJson(config.iOSFontInfo!);
    }

    if (config.androidFontInfo != null) {
      json["androidFontInfo"] =
          AndroidFontInfoUtil.toJson(config.androidFontInfo!);
    }

    if (config.gradientDrawable != null) {
      json["gradientDrawable"] =
          _convertGradientDrawableToJson(config.gradientDrawable!);
    }

    return json;
  }

  static Map<String, dynamic> _convertPlayIconConfigToJson(
      VideoFeedPlayIconConfiguration config) {
    Map<String, dynamic> json = {};
    if (config.hidden != null) {
      json["hidden"] = config.hidden!;
    }

    if (config.iconWidth != null) {
      json["iconWidth"] = config.iconWidth!.toDouble();
    }
    return json;
  }

  static Map<String, dynamic> _convertContentPaddingToJson(
      VideoFeedContentPadding contentPadding) {
    Map<String, dynamic> json = {};
    if (contentPadding.top != null) {
      json["top"] = contentPadding.top!;
    }

    if (contentPadding.right != null) {
      json["right"] = contentPadding.right!;
    }

    if (contentPadding.bottom != null) {
      json["bottom"] = contentPadding.bottom!;
    }

    if (contentPadding.left != null) {
      json["left"] = contentPadding.left!;
    }

    return json;
  }

  static Map<String, dynamic> toJson(VideoFeedConfiguration? config) {
    Map<String, dynamic> json = {};
    if (config == null) {
      return json;
    }

    if (config.backgroundColor != null && config.backgroundColor!.isNotEmpty) {
      json["backgroundColor"] = config.backgroundColor!;
    }

    if (config.cornerRadius != null) {
      json["cornerRadius"] = config.cornerRadius!;
    }

    if (config.title != null) {
      json["title"] = _convertTitleConfigToJson(config.title!);
    }

    if (config.titlePosition != null) {
      json["titlePosition"] = config.titlePosition!.name;
    }

    if (config.playIcon != null) {
      json["playIcon"] = _convertPlayIconConfigToJson(config.playIcon!);
    }

    if (config.showAdBadge != null) {
      json["showAdBadge"] = config.showAdBadge!;
    }

    if (config.aspectRatio != null) {
      json["aspectRatio"] = config.aspectRatio!;
    }

    if (config.contentPadding != null) {
      json["contentPadding"] =
          _convertContentPaddingToJson(config.contentPadding!);
    }

    if (config.itemSpacing != null) {
      json["itemSpacing"] = config.itemSpacing!;
    }

    if (config.enableAutoplay != null) {
      json["enableAutoplay"] = config.enableAutoplay!;
    }

    if (config.gridColumns != null) {
      json["gridColumns"] = config.gridColumns!;
    }

    return json;
  }
}
